==> libkcddb-4.14.1.tar.xz: libkcddb-4.14.1/libkcddb/synccddbplookup.h <==
/*
  Copyright (C) 2002 Rik Hemsley (rikkus) <rik@kde.org>
  Copyright (C) 2002 Benjamin Meyer <ben-devel@meyerhome.net>
  Copyright (C) 2002 Nadeem Hasan <nhasan@kde.org>

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Library General Public License for more details.

  You should have received a copy of the GNU Library General Public License
  along with this library; see the file COPYING.LIB.  If not, write to
  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  Boston, MA 02110-1301, USA.
*/

#ifndef KCDDB_SYNC_CDDBP_LOOKUP_H
#define KCDDB_SYNC_CDDBP_LOOKUP_H

#include "cddbplookup.h"

namespace KCDDB
{
  class SyncCDDBPLookup : public CDDBPLookup
  {
    public:

      SyncCDDBPLookup();
      virtual ~SyncCDDBPLookup();

      Result lookup( const QString &, uint, const TrackOffsetList & );

      CDInfoList lookupResponse() const;

    protected:
      Result shakeHands();
      Result runQuery();
      Result matchToCDInfo( const CDDBMatch & );

      QString readLine();
  };
}

#endif // KCDDB_SYNC_CDDBP_LOOKUP_H
// vim:tabstop=2:shiftwidth=2:expandtab:cinoptions=(s,U1,m1

==> libkcddb_17.08.3.orig.tar.xz: libkcddb-17.08.3/libkcddb/synccddbplookup.h <==
/*
  Copyright (C) 2002 Rik Hemsley (rikkus) <rik@kde.org>
  Copyright (C) 2002 Benjamin Meyer <ben-devel@meyerhome.net>
  Copyright (C) 2002 Nadeem Hasan <nhasan@kde.org>

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Library General Public License for more details.

  You should have received a copy of the GNU Library General Public License
  along with this library; see the file COPYING.LIB.  If not, write to
  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  Boston, MA 02110-1301, USA.
*/

#ifndef KCDDB_SYNC_CDDBP_LOOKUP_H
#define KCDDB_SYNC_CDDBP_LOOKUP_H

#include "cddbplookup.h"

namespace KCDDB
{
  class SyncCDDBPLookup : public CDDBPLookup
  {
    public:

      SyncCDDBPLookup();
      virtual ~SyncCDDBPLookup();

      Result lookup( const QString &, uint, const TrackOffsetList & ) Q_DECL_OVERRIDE;

      CDInfoList lookupResponse() const;

    protected:
      Result shakeHands();
      Result runQuery();
      Result matchToCDInfo( const CDDBMatch & );

      QString readLine();
  };
}

#endif // KCDDB_SYNC_CDDBP_LOOKUP_H
// vim:tabstop=2:shiftwidth=2:expandtab:cinoptions=(s,U1,m1
